#!/bin/bash

SourceDir=`pwd`          # Where is our source code?
if [ ! -e required_version ]; then #{
  echo "$0 - ERROR: compiling in incorrect folder!";
  echo "Create a copy of template project via createNewProject.pl and try again!"
  exit 10
fi #}
RequiredVersion=`cat required_version`

#{ obtain ToolChain_STM32 (if not already done)
cd
if [ ! -d Source ]; then
  mkdir Source
fi
cd Source
if [ -d ToolChain_STM32 ]; then
  mv ToolChain_STM32 ToolChain_STM32_DELETE
fi
if [ -e ToolChain_STM32 ]; then
  rm ToolChain_STM32
fi
if [ -e ToolChain_STM32 ]; then
  echo "$0 - ERROR: Cannot move away `pwd`/ToolChain_STM32 !"
  exit 11
fi

Folder="ToolChain_STM32_${RequiredVersion}"
if [ ! -d $Folder ]; then #{ download missing toolchain version
  echo "downloading $Folder.."
  wget -c http://hlb-labor.de/projekte/cortexm3/archive/${Folder}.tar.bz
  tar xjf ${Folder}.tar.bz
  if [ -d ToolChain_STM32 ]; then
    mv ToolChain_STM32 ${Folder}
  fi
fi
#}
ln -s ${Folder} ToolChain_STM32

cd ToolChain_STM32/ToolChain/
if [ ! -e AllInstallsOK ]; then
  echo "Installation incomplete: Starting toolchain installation.."
  ./installAll.sh
fi
#}

cd $SourceDir            # cd back to this source code directory
./createLinks.sh         # recreate symbolic links to ToolChain_STM32
source ./_/SourceMe.sh   # update path variables to binary tools
./_/compile.sh           # compile source
./_/updateProjectFiles.pl QtCreator/Test_LCD_ST7881.files ../ >QtCreator/Test_LCD_ST7881.files.log

#{ flash onto uC
if [ -e main.bin ]; then
  echo "Trying to flash binary onto microcontroller.."
  ./_/flash.sh main.bin || echo "Note: configure file _/interface.cfg according to your JTAG-programmer!"
fi
#}
