#!/usr/bin/perl -w

use strict;
use File::Spec::Functions qw(rel2abs);
use File::Basename;
my $ToolChainDir = dirname(rel2abs($0));

my $ProjectName = shift(@ARGV);
my $AuthorName  = shift(@ARGV);

my $ProjectDir = rel2abs($ToolChainDir.'/../'.$ProjectName);

unless ($AuthorName) {
  print "$0 PROJECT_NAME AUTHOR_NAME\n";
  print "Creates a new copy of Template project. Automatically sets project name and author in all files.\n";
  print "\n";
  exit 5;
}

unless ( -d "$ToolChainDir/Template" ) {
  print STDERR "$0 ERROR: Cannot find folder Template in $ToolChainDir/ !\n";
  exit 10;
}
if (-d $ProjectName) {
  print STDERR "$0 ERROR: Directory $ProjectName already exists in `pwd` !\n";
  exit 11;
}
if (-e $ProjectName) {
  print STDERR "$0 ERROR: File $ProjectName is in the way in `pwd` !\n";
  exit 12;
}

print "Creating new project $ProjectName for $AuthorName in $ProjectDir/\n";
system("cp -R '$ToolChainDir/Template' $ProjectDir/");
system("cp '$ToolChainDir/Version' $ProjectDir/required_version");
unless (-d $ProjectDir) {
  print STDERR "$0 ERROR: Cannot create directory $ProjectDir in `pwd` !\n";
  exit 13;
}
chdir($ProjectDir);
system("./_/clean.sh");
foreach my $FileName (qw( TemplateName.config  TemplateName.creator  TemplateName.creator.user  TemplateName.files  TemplateName.includes ) ) {
  my $OrigFileNames = `find ./ -name $FileName`;
  my @OrigFileNames = split("\n", $OrigFileNames);
  foreach my $OrigFileName (@OrigFileNames) {
    my $NewName = $OrigFileName;
    $NewName =~ s/TemplateName/$ProjectName/;
    print "$OrigFileName -> $NewName\n";
    rename($OrigFileName, $NewName);
  }
}

print "searching for files to be processed...\n";
my @Files2Process;
foreach my $Keyword ( qw(TemplateName TemplateAuthor) ) {
  my $FilesFound = `grep -R $Keyword *`;
  my @FilesFound = split("\n", $FilesFound);
  foreach my $FileFound (@FilesFound) {
    my @Parts = split(':', $FileFound);
    my $FileName = $Parts[0];
    if ($FileName) {
      push @Files2Process, $FileName;
    }
  }
}

my $Error = '';
foreach my $File2Process (@Files2Process) { # replace TemplateName, TemplateAuthor in all files
  my $OldError = $Error;
  open(IN, "<$File2Process") or $Error .= "Cannot read from file '$File2Process' ($!)\n";
  my @Lines;
  if ($OldError eq $Error) {
    @Lines = <IN>;
    close(IN);
    print "modifying $File2Process..\n";
    foreach my $Line (@Lines) {
      $Line =~ s/TemplateName/$ProjectName/g;
      $Line =~ s/TemplateAuthor/$AuthorName/g;
    }
    $OldError = $Error;
    open(OUT, ">$File2Process") or $Error .= "Cannot write to file '$File2Process' ($!)\n";
    if ($OldError eq $Error) {
      print OUT join("", @Lines);
      close(OUT);
    }
  }
  if ($Error) { print $Error; }
}


print "\n";
print "Project $ProjectName has been created successfully.\n";
my $PWD = `pwd`; chop($PWD);
print <<"END_OF_INFO";

Next steps:

1) connect JTAG programmer (e.g. Olimex ARB-USB TinyH) to USB port
2) connect prototype board with Cortex M3 microcontroller 
   (e.g. Olimex STM32-H107) to JTAG programmer.
3) cd $PWD
4) ./compile.sh
   -> read compile.txt
5) qtcreator &
   -> open QtCreator/$ProjectName.creator

END_OF_INFO


exit 0;
